@@ -44,6 +44,7 @@
 
 #include "mozplugger.h"
 #include "debug.h"
+#include "npn-get-helpers.h"
 
 #ifndef __GNUC__
 #define __inline
@@ -142,10 +143,7 @@ static const char *controller_fname;
 static const char *linker_fname;
 static handler_t * handlers = 0;
 
-static int            browserApiMajorVer;
-static int            browserApiMinorVer;
 static NPBool         browserSupportsXEmbed;
-static NPNToolkitType browserToolkit;
 
 static char staticPool[MAX_STATIC_MEMORY_POOL];
 static int  staticPoolIdx = 0;
@@ -730,9 +728,14 @@ static void read_config(FILE *f)
 
      while (fgets(buffer, sizeof(buffer), f))
      {
+	  if (buffer[0] == '\n' || buffer[0] == '\0')
+          {
+	       continue;
+          }
+
 	  D("::: %s", buffer);
 
-	  if (buffer[0] == '#' || buffer[0] == '\n' || buffer[0] == '\0')
+	  if (buffer[0] == '#')
           {
 	       continue;
           }
@@ -778,9 +781,7 @@ static void read_config(FILE *f)
                         D("previous handler has no commands, so dropped\n");
                     }
 
-		    D("-------------------------------------------\n");
-		    D("Starting new handler\n");
-		    D("-------------------------------------------\n");
+		    D("------------ Starting new handler ---------\n");
 
 		    handler = (handler_t *) allocStaticMem(sizeof(handler_t));
                     if(handler == 0)
@@ -1073,15 +1074,14 @@ static int read_config_cb(const char *fname)
      int fd;
      FILE *fp;
 
-     D("READ_CONFIG(%s)\n", fname);
-
      fd = open(fname, O_RDONLY);
      if (fd < 0)
      {
           /* Not an error! */
-          D("could not open '%s'\n", fname);
+          D("READ_CONFIG(%s) - could not open\n", fname);
           return 0;
      }
+     D("READ_CONFIG(%s) - file opened\n", fname);
 
      if (pipe(m4out) < 0)
      {
@@ -1222,52 +1222,6 @@ static int find_plugger_linker_cb(const char *fname)
      return 1;
 }
 
-/*****************************************************************************/
-/**
- * Get information about the browser this plugin is running under
- *
- */
-static void get_browser_info(void)
-{
-     int pluginApiMajorVer;
-     int pluginApiMinorVer;
-     NPError err;
-
-     NPN_Version(&pluginApiMajorVer,  &pluginApiMinorVer,
-                 &browserApiMajorVer, &browserApiMinorVer);
-
-     D("get_browser_info() - API versions plugin=%d.%d Browser=%d.%d\n", 
-             pluginApiMajorVer, pluginApiMinorVer,
-             browserApiMajorVer, browserApiMinorVer);
-
-     /* Check if browser supports XEmbed and also what toolkit the browser 
-      * uses */
-     err = NPN_GetValue(NULL, NPNVSupportsXEmbedBool, 
-                                                (void*) &browserSupportsXEmbed);
-     if(err != NPERR_NO_ERROR)
-     {
-          D("get_bowser_info() - Error getting Supports XEmbed, err=%i\n", err);
-          browserSupportsXEmbed = 0;
-     }
-     if(browserSupportsXEmbed)
-     {
-          D("get_browser_info() - Browser supports XEmbed\n");
-     }
-     err = NPN_GetValue(NULL, NPNVToolkit, (void *) &browserToolkit);
-     if(err != NPERR_NO_ERROR)
-     {
-          browserToolkit = 0;
-     }
-     if(browserToolkit == NPNVGtk12)
-     {
-          D("get_browser_info() - Browser supports GTK1.2\n");
-     }
-     else if(browserToolkit == NPNVGtk2)
-     {
-          D("get_browser_info() - Browser supports GTK2\n");
-     }
-}
-
 /*****************************************************************************/
 /** 
  * Find configuration file, helper and controller executables. Call the
@@ -1726,7 +1680,7 @@ static int find_command(data_t * const THIS, int streamOnly)
  * @return Pointer to string containing mime decription for this plugin
  *
  *****************************************************************************/
-char *NPP_GetMIMEDescription(void)
+const char *NPP_GetMIMEDescription(void)
 {
      char *x,*y;
      handler_t *h;
@@ -1788,7 +1742,7 @@ char *NPP_GetMIMEDescription(void)
 
      D("Getmimedescription done: %s\n", x);
 
-     return x;
+     return (const char *)x;
 }
 
 /*****************************************************************************/
@@ -2148,6 +2102,14 @@ NPError NPP_GetValue(void *instance, NPPVariable variable, void *value)
 	            varName = "NPPVpluginUrlRequestsDisplayedBool"; break;
                case NPPVpluginWantsAllNetworkStreams:
 	            varName = "NPPVpluginWantsNetworkStreams"; break;
+               case NPPVpluginNativeAccessibleAtkPlugId:
+                    varName = "NPPVpluginNativeAccessibleAtkPlugId"; break;
+               case NPPVpluginCancelSrcStream:
+                    varName = "NPPVpluginCancelSrcStream"; break;
+               case NPPVsupportsAdvancedKeyHandling: 
+                    varName = "NPPVsupportsAdvancedKeyHandling"; break;
+               case NPPVpluginUsesDOMForCursorBool:
+                    varName = "NPPVpluginUsesDOMForCursorBool"; break;
 	       default:
 		    varName = ""; break;
 	       }
@@ -2980,8 +2942,7 @@ static void resize_window(NPP instance)
      XSetWindowAttributes attrib;
      data_t * THIS;
 
-     /* Mozilla work around not require for versions > 0.13 */
-     if((browserApiMajorVer > 0) || (browserApiMinorVer > 13))
+     if(!does_browser_have_resize_bug())
      {
           return;
      }
@@ -3098,6 +3059,10 @@ NPError NPP_SetWindow(NPP instance, NPWindow* window)
 
      /* In case Mozilla would call NPP_SetWindow() in a loop. */
      usleep(4000);
+
+//     get_browser_toolkit(instance);
+//     does_browser_support_key_handling(instance);
+
      return NPERR_NO_ERROR;
 }
 
@@ -3161,7 +3126,9 @@ NPError NPP_Initialize(void)
 {
      D("NPP_Initialize(void)\n");
 
-     get_browser_info();
+     get_api_version();
+
+     browserSupportsXEmbed = does_browser_support_xembed();
 
      do_read_config();
 
@@ -3309,3 +3276,98 @@ void NPP_URLNotify(NPP instance, const char * url, NPReason reason, void * notif
 {
      D("NPP_URLNotify() - instance=%p url=%s reason=%i\n", instance, url, reason);
 }
+
+/*****************************************************************************/
+/**
+ * NPP Got Focus
+ * Called by the browser when the browser intends to focus an instance.
+ * Instance argument indicates the instance getting focus.
+ * Direction argument indicates the direction in which focus advanced to the instance.
+ * Return value indicates whether or not the plugin accepts focus.
+ * Currently not used by mozplugger
+ *
+ * @param[in] instance   Pointer to the plugin instance data
+ * @param[in] direction  The advancement direction
+ *
+ * @return True or False
+ *
+ *****************************************************************************/
+NPBool NPP_GotFocus(NPP instance, NPFocusDirection direction)
+{
+    D("NPP_GotFocus() - instance=%p, direction=%i\n", instance, direction);
+    return false;
+}
+
+/*****************************************************************************/
+/**
+ * NPP Lost Focus
+ * Called by the browser when the browser intends to take focus.
+ * Instance argument indicates the instances losing focus.
+ * There is no return value, plugins will lose focus when this is called.
+ * Currently not used by mozplugger
+ *
+ * @param[in] instance   Pointer to the plugin instance data
+ *
+ * @return True or False
+ *
+ *****************************************************************************/
+void NPP_LostFocus(NPP instance)
+{
+     D("NPP_LostFocus() - instance=%p\n", instance);
+}
+
+/*****************************************************************************/
+/**
+ * NPP URL Redirect Notify
+ * Currently not used by mozplugger
+ *
+ * @param[in] instance   Pointer to the plugin instance data
+ * @param[in] url        The URL that was GET or POSTed
+ * @param[in] status     ??
+ * @param[in] notifyData Data that was passed in the original call to Get or Post URL
+ *
+ * @return None
+ *
+ *****************************************************************************/
+void NPP_URLRedirectNotify(NPP instance, const char * url, int32_t status, void * noifyData)
+{
+     D("NPP_URLRedirectNotify() - instance=%p, url=%s, status=%i\n", instance, url, status);
+}
+
+/*****************************************************************************/
+/**
+ * NPP Clear Site Data
+ * Clear site data held by plugin (should this clear tmp files?)
+ * Currently not used by mozplugger
+ *
+ * @param[in] site   The site name
+ * @param[in] flags
+ * @param[in] maxAge
+ *
+ * @return Error status
+ *
+ *****************************************************************************/
+NPError NPP_ClearSiteData(const char * site, uint64_t flags, uint64_t maxAge)
+{
+     D("NPP_ClearSiteData() - site=%s\n", site);
+     return NPERR_NO_ERROR;
+}
+
+/*****************************************************************************/
+/**
+ * NPP Ge Site Data
+ * Get list of sites plugin has data for (should this be list of tmp files?)
+ * Currently not used by mozplugger
+ *
+ * @param[in] site   The site name
+ * @param[in] flags
+ * @param[in] maxAge
+ *
+ * @return Error status
+ *
+ *****************************************************************************/
+char** NPP_GetSitesWithData(void)
+{
+    D("NPP_GetSitesWithData()\n");
+    return 0;
+}
