@@ -281,8 +281,7 @@ void NPN_ReloadPlugins(NPBool reloadPages)
 }
 
 /******************************************************************************/
-void
-NPN_InvalidateRect(NPP instance, NPRect *invalidRect)
+void NPN_InvalidateRect(NPP instance, NPRect *invalidRect)
 {
     NPN_InvalidateRectProcPtr func = gNetscapeFuncs.invalidaterect;
     if(func)
@@ -292,8 +291,7 @@ NPN_InvalidateRect(NPP instance, NPRect *invalidRect)
 }
 
 /******************************************************************************/
-void
-NPN_InvalidateRegion(NPP instance, NPRegion invalidRegion)
+void NPN_InvalidateRegion(NPP instance, NPRegion invalidRegion)
 {
     NPN_InvalidateRegionProcPtr func = gNetscapeFuncs.invalidateregion;
     if(func)
@@ -303,8 +301,7 @@ NPN_InvalidateRegion(NPP instance, NPRegion invalidRegion)
 }
 
 /******************************************************************************/
-void
-NPN_ForceRedraw(NPP instance)
+void NPN_ForceRedraw(NPP instance)
 {
     NPN_ForceRedrawProcPtr func = gNetscapeFuncs.forceredraw;
     if(func)
@@ -691,6 +688,40 @@ NPBool NPN_ConvertPoint(NPP instance, double sourceX, double sourceY,
     return retVal;
 }
 
+/******************************************************************************/
+NPBool NPN_HandleEvent(NPP instance, void *event, NPBool handled)
+{
+    NPN_HandleEventPtr func = gNetscapeFuncs.handleevent;
+    NPBool retVal = false;
+    if(func)
+    {
+        retVal = (*func)(instance, event, handled);
+    }
+    return retVal;
+}
+
+/******************************************************************************/
+NPBool NPN_UnfocusInstance(NPP instance, NPFocusDirection direction)
+{
+    NPN_UnfocusInstancePtr func = gNetscapeFuncs.unfocusinstance;
+    NPBool retVal = False;
+    if(func)
+    {
+        retVal = (*func)(instance, direction);
+    }
+    return retVal;
+}
+
+
+/******************************************************************************/
+void NPN_URLRedirectResponse(NPP instance, void* notifyData, NPBool allow)
+{
+    NPN_URLRedirectResponsePtr func = gNetscapeFuncs.urlredirectresponse;
+    if(func)
+    {
+        (*func)(instance, notifyData, allow);
+    }
+}
 
 /*********************************************************************** 
  *
@@ -703,8 +734,7 @@ NPBool NPN_ConvertPoint(NPP instance, double sourceX, double sourceY,
  *  - The browser uses the return value to indicate to the user what version of
  *    this plugin is installed.
  */
-char *
-NP_GetPluginVersion(void)
+char * NP_GetPluginVersion(void)
 {
     return VERSION;
 }
@@ -716,8 +746,7 @@ NP_GetPluginVersion(void)
  *  - Netscape uses the return value to identify when an object instance
  *    of this plugin should be created.
  */
-char *
-NP_GetMIMEDescription(void)
+const char * NP_GetMIMEDescription(void)
 {
     return NPP_GetMIMEDescription();
 }
@@ -728,8 +757,7 @@ NP_GetMIMEDescription(void)
  *  - Interfaces with plugin to get values for predefined variables
  *    that the navigator needs.
  */
-NPError
-NP_GetValue(void* future, NPPVariable variable, void *value)
+NPError NP_GetValue(void* future, NPPVariable variable, void *value)
 {
     return NPP_GetValue(future, variable, value);
 }
@@ -751,8 +779,7 @@ NP_GetValue(void* future, NPPVariable variable, void *value)
  *        library will use this function table to call the plugin.
  *
  */
-NPError
-NP_Initialize(NPNetscapeFuncs* nsTable, NPPluginFuncs* pluginFuncs)
+NPError NP_Initialize(NPNetscapeFuncs* nsTable, NPPluginFuncs* pluginFuncs)
 {
     NPError err = NPERR_NO_ERROR;
 
@@ -814,7 +841,12 @@ NP_Initialize(NPNetscapeFuncs* nsTable, NPPluginFuncs* pluginFuncs)
         funcs.urlnotify     = NPP_URLNotify;
         funcs.getvalue      = (NPP_GetValueProcPtr) NPP_GetValue;
         funcs.setvalue      = NPP_SetValue;
-               
+        funcs.gotfocus      = NPP_GotFocus;
+        funcs.lostfocus     = NPP_LostFocus;
+        funcs.urlredirectnotify = NPP_URLRedirectNotify;
+        funcs.clearsitedata = NPP_ClearSiteData;
+        funcs.getsiteswithdata = NPP_GetSitesWithData;
+
         if(pluginFuncs->size > sizeof(NPPluginFuncs))
         {   
             /* Zero the fields we dont have anything for */
@@ -850,8 +882,7 @@ NP_Initialize(NPNetscapeFuncs* nsTable, NPPluginFuncs* pluginFuncs)
  *    the last object of this kind has been destroyed.
  *
  */
-NPError
-NP_Shutdown(void)
+NPError NP_Shutdown(void)
 {
     NPP_Shutdown();
     return NPERR_NO_ERROR;
