@@ -54,23 +54,23 @@
 
 
 /*----------------------------------------------------------------------*/
-/*                   Plugin Version Constants                           */
+/*                        Plugin Version Constants                      */
 /*----------------------------------------------------------------------*/
 
 #define NP_VERSION_MAJOR 0
-#define NP_VERSION_MINOR 23
+#define NP_VERSION_MINOR 27
 
 /*----------------------------------------------------------------------*/
-/*                   Definition of Basic Types                          */
+/*                       Definition of Basic Types                      */
 /*----------------------------------------------------------------------*/
- 
-typedef unsigned char	NPBool;
-typedef int16_t         NPError;
-typedef int16_t		NPReason;
-typedef char*		NPMIMEType;
+
+typedef unsigned char NPBool;
+typedef int16_t       NPError;
+typedef int16_t       NPReason;
+typedef char*         NPMIMEType;
 
 /*----------------------------------------------------------------------*/
-/*                   Structures and definitions                         */
+/*                       Structures and definitions                     */
 /*----------------------------------------------------------------------*/
 
 /*
@@ -78,64 +78,71 @@ typedef char*		NPMIMEType;
  */
 typedef struct _NPP
 {
-    void*	pdata;			/* plug-in private data */
-    void*	ndata;			/* netscape private data */
+  void* pdata;      /* plug-in private data */
+  void* ndata;      /* netscape private data */
 } NPP_t;
 
 typedef NPP_t*  NPP;
 
-
 typedef struct _NPStream
 {
-  void* pdata;		/* plug-in private data */
-  void* ndata;		/* netscape private data */
-  const char* url;
+  void*    pdata; /* plug-in private data */
+  void*    ndata; /* netscape private data */
+  const    char* url;
   uint32_t end;
   uint32_t lastmodified;
-  void* notifyData;
-  const  char* headers; /* Response headers from host.
-                         * Exists only for >= NPVERS_HAS_RESPONSE_HEADERS.
-                         * Used for HTTP only; NULL for non-HTTP.
-                         * Available from NPP_NewStream onwards.
-                         * Plugin should copy this data before storing it.
-                         * Includes HTTP status line and all headers,
-                         * preferably verbatim as received from server,
-                         * headers formatted as in HTTP ("Header: Value"),
-                         * and newlines (\n, NOT \r\n) separating lines.
-                         * Terminated by \n\0 (NOT \n\n\0). */
+  void*    notifyData;
+  const    char* headers; /* Response headers from host.
+                           * Exists only for >= NPVERS_HAS_RESPONSE_HEADERS.
+                           * Used for HTTP only; NULL for non-HTTP.
+                           * Available from NPP_NewStream onwards.
+                           * Plugin should copy this data before storing it.
+                           * Includes HTTP status line and all headers,
+                           * preferably verbatim as received from server,
+                           * headers formatted as in HTTP ("Header: Value"),
+                           * and newlines (\n, NOT \r\n) separating lines.
+                           * Terminated by \n\0 (NOT \n\n\0). */
 } NPStream;
 
-
 typedef struct _NPByteRange
 {
-    int32_t	offset;			/* negative offset means from the end */
-    uint32_t	length;
-    struct _NPByteRange* next;
+  int32_t  offset; /* negative offset means from the end */
+  uint32_t length;
+  struct _NPByteRange* next;
 } NPByteRange;
 
-
 typedef struct _NPSavedData
 {
-    int32_t	len;
-    void*	buf;
+  int32_t len;
+  void*   buf;
 } NPSavedData;
 
-
 typedef struct _NPRect
 {
-    uint16_t	top;
-    uint16_t	left;
-    uint16_t	bottom;
-    uint16_t	right;
+  uint16_t top;
+  uint16_t left;
+  uint16_t bottom;
+  uint16_t right;
 } NPRect;
 
-typedef struct _NPSize 
-{ 
-  int32_t width; 
-  int32_t height; 
-} NPSize; 
+typedef struct _NPSize
+{
+  int32_t width;
+  int32_t height;
+} NPSize;
 
-#ifdef XP_UNIX
+typedef enum {
+  NPFocusNext = 0,
+  NPFocusPrevious = 1
+} NPFocusDirection;
+
+/* Return values for NPP_HandleEvent */
+#define kNPEventNotHandled 0
+#define kNPEventHandled 1
+/* Exact meaning must be spec'd in event model. */
+#define kNPEventStartIME 2
+
+#if defined(XP_UNIX)
 /*
  * Unix specific structures and definitions
  */
@@ -147,21 +154,21 @@ typedef struct _NPSize
  */
 enum {
   NP_SETWINDOW = 1,
-  NP_PRINT    
+  NP_PRINT
 };
 
 typedef struct
 {
-    int32_t		type;
+  int32_t type;
 } NPAnyCallbackStruct;
 
 typedef struct
 {
-    int32_t			type;
-    Display*		display;
-    Visual*			visual;
-    Colormap		colormap;
-    unsigned int	depth;
+  int32_t      type;
+  Display*     display;
+  Visual*      visual;
+  Colormap     colormap;
+  unsigned int depth;
 } NPSetWindowCallbackStruct;
 
 typedef struct
@@ -174,21 +181,21 @@ typedef struct
 
 
 /*
- *   The following masks are applied on certain platforms to NPNV and 
- *   NPPV selectors that pass around pointers to COM interfaces. Newer 
- *   compilers on some platforms may generate vtables that are not 
- *   compatible with older compilers. To prevent older plugins from 
- *   not understanding a new browser's ABI, these masks change the 
+ *   The following masks are applied on certain platforms to NPNV and
+ *   NPPV selectors that pass around pointers to COM interfaces. Newer
+ *   compilers on some platforms may generate vtables that are not
+ *   compatible with older compilers. To prevent older plugins from
+ *   not understanding a new browser's ABI, these masks change the
  *   values of those selectors on those platforms. To remain backwards
- *   compatible with different versions of the browser, plugins can 
+ *   compatible with different versions of the browser, plugins can
  *   use these masks to dynamically determine and use the correct C++
- *   ABI that the browser is expecting. This does not apply to Windows 
+ *   ABI that the browser is expecting. This does not apply to Windows
  *   as Microsoft's COM ABI will likely not change.
  */
 
 #define NP_ABI_GCC3_MASK  0x10000000
 /*
- *   gcc 3.x generated vtables on UNIX and OSX are incompatible with 
+ *   gcc 3.x generated vtables on UNIX and OSX are incompatible with
  *   previous compilers.
  */
 #if (defined(XP_UNIX) && defined(__GNUC__) && (__GNUC__ >= 3))
@@ -209,10 +216,9 @@ typedef enum {
   NPPVpluginDescriptionString,
   NPPVpluginWindowBool,
   NPPVpluginTransparentBool,
-  NPPVjavaClass,                /* Not implemented in Mozilla 1.0 */
+  NPPVjavaClass,
   NPPVpluginWindowSize,
   NPPVpluginTimerInterval,
-
   NPPVpluginScriptableInstance = (10 | NP_ABI_MASK),
   NPPVpluginScriptableIID = 11,
 
@@ -231,7 +237,7 @@ typedef enum {
   /* Get the plugin value (as \0-terminated UTF-8 string data) for
    * form submission if the plugin is part of a form. Use
    * NPN_MemAlloc() to allocate memory for the string data. Introduced
-   * in Mozilla 1.8b2 (NPAPI minor version 15).
+   * in NPAPI minor version 15.
    */
   NPPVformValue = 16,
 
@@ -240,7 +246,19 @@ typedef enum {
   /* Checks if the plugin is interested in receiving the http body of
    * all http requests (including failed ones, http status != 200).
    */
-  NPPVpluginWantsAllNetworkStreams = 18
+  NPPVpluginWantsAllNetworkStreams = 18,
+
+  /* Browsers can retrieve a native ATK accessibility plug ID via this variable. */
+  NPPVpluginNativeAccessibleAtkPlugId = 19,
+
+  /* Checks to see if the plug-in would like the browser to load the "src" attribute. */
+  NPPVpluginCancelSrcStream = 20,
+
+  NPPVsupportsAdvancedKeyHandling = 21,
+
+  NPPVpluginUsesDOMForCursorBool = 22
+
+
 
 #ifdef MOZ_PLATFORM_HILDON
   , NPPVpluginWindowlessLocalBool = 2002
@@ -248,7 +266,7 @@ typedef enum {
 } NPPVariable;
 
 /*
- * List of variable names for which NPN_GetValue is implemented by Mozilla
+ * List of variable names for which NPN_GetValue should be implemented.
  */
 typedef enum {
   NPNVxDisplay = 1,
@@ -260,7 +278,7 @@ typedef enum {
 
   /* 10 and over are available on Mozilla builds starting with 0.9.4 */
   NPNVserviceManager = (10 | NP_ABI_MASK),
-  NPNVDOMElement     = (11 | NP_ABI_MASK),   /* available in Mozilla 1.2 */
+  NPNVDOMElement     = (11 | NP_ABI_MASK),
   NPNVDOMWindow      = (12 | NP_ABI_MASK),
   NPNVToolkit        = (13 | NP_ABI_MASK),
   NPNVSupportsXEmbedBool = 14,
@@ -273,7 +291,11 @@ typedef enum {
 
   NPNVSupportsWindowless = 17,
 
-  NPNVprivateModeBool = 18
+  NPNVprivateModeBool = 18,
+
+  NPNVsupportsAdvancedKeyHandling = 21,
+
+  NPNVdocumentOrigin = 22
 
 #ifdef MOZ_PLATFORM_HILDON
   , NPNVSupportsWindowlessLocal = 2002
@@ -301,7 +323,7 @@ typedef enum {
   NPWindowTypeDrawable
 } NPWindowType;
 
-typedef struct _NPWindow 
+typedef struct _NPWindow
 {
   void* window;  /* Platform specific window handle */
                  /* OS/2: x - Position of bottom left corner */
@@ -335,32 +357,32 @@ typedef struct _NPImageExpose
 
 typedef struct _NPFullPrint
 {
-    NPBool	pluginPrinted;/* Set TRUE if plugin handled fullscreen printing */
-    NPBool	printOne;      /* TRUE if plugin should print one copy to default
-                                  printer */
-    void*	platformPrint; /* Platform-specific printing info */
+  NPBool pluginPrinted;/* Set TRUE if plugin handled fullscreen printing */
+  NPBool printOne;     /* TRUE if plugin should print one copy to default
+                          printer */
+  void* platformPrint; /* Platform-specific printing info */
 } NPFullPrint;
 
 typedef struct _NPEmbedPrint
 {
-    NPWindow	window;
-    void*	platformPrint;	/* Platform-specific printing info */
+  NPWindow window;
+  void* platformPrint; /* Platform-specific printing info */
 } NPEmbedPrint;
 
 typedef struct _NPPrint
 {
-    uint16_t	mode;						/* NP_FULL or NP_EMBED */
-    union
-    {
-		NPFullPrint		fullPrint;		/* if mode is NP_FULL */
-		NPEmbedPrint	embedPrint;		/* if mode is NP_EMBED */
-    } print;
+  uint16_t mode;               /* NP_FULL or NP_EMBED */
+  union
+  {
+    NPFullPrint fullPrint;   /* if mode is NP_FULL */
+    NPEmbedPrint embedPrint; /* if mode is NP_EMBED */
+  } print;
 } NPPrint;
 
 #if defined (XP_UNIX)
 typedef XEvent NPEvent;
 #else
-typedef void*			NPEvent;
+typedef void*  NPEvent;
 #endif
 
 #if defined(XP_UNIX)
@@ -386,22 +408,22 @@ typedef enum {
 /*
  * Values for mode passed to NPP_New:
  */
-#define NP_EMBED		1
-#define NP_FULL			2
+#define NP_EMBED 1
+#define NP_FULL  2
 
 /*
  * Values for stream type passed to NPP_NewStream:
  */
-#define NP_NORMAL		1
-#define NP_SEEK			2
-#define NP_ASFILE		3
-#define NP_ASFILEONLY		4
+#define NP_NORMAL     1
+#define NP_SEEK       2
+#define NP_ASFILE     3
+#define NP_ASFILEONLY 4
 
-#define NP_MAXREADY	(((unsigned)(~0)<<1)>>1)
+#define NP_MAXREADY (((unsigned)(~0)<<1)>>1)
 
 
 /*----------------------------------------------------------------------*/
-/*                   Error and Reason Code definitions                  */
+/*       Error and Reason Code definitions                              */
 /*----------------------------------------------------------------------*/
 
 /*
@@ -422,6 +444,8 @@ typedef enum {
 #define NPERR_FILE_NOT_FOUND              (NPERR_BASE + 11)
 #define NPERR_NO_DATA                     (NPERR_BASE + 12)
 #define NPERR_STREAM_NOT_SEEKABLE         (NPERR_BASE + 13)
+#define NPERR_TIME_RANGE_NOT_SUPPORTED    (NPERR_BASE + 14)
+#define NPERR_MALFORMED_SITE              (NPERR_BASE + 15)
 
 /*
  * Values of type NPReason:
@@ -455,6 +479,11 @@ typedef enum {
 #define NPVERS_HAS_PLUGIN_THREAD_ASYNC_CALL 19
 #define NPVERS_HAS_ALL_NETWORK_STREAMS      20
 #define NPVERS_HAS_URL_AND_AUTH_INFO        21
+#define NPVERS_HAS_PRIVATE_MODE             22
+#define NPVERS_MACOSX_HAS_COCOA_EVENTS      23
+#define NPVERS_HAS_ADVANCED_KEY_HANDLING    25
+#define NPVERS_HAS_URL_REDIRECT_HANDLING    26
+#define NPVERS_HAS_CLEAR_SITE_DATA          27
 
 /*----------------------------------------------------------------------*/
 /*                        Function Prototypes                           */
@@ -468,8 +497,8 @@ extern "C" {
 
 /* NPP_* functions are provided by the plugin and called by the navigator. */
 
-#ifdef XP_UNIX
-char* NPP_GetMIMEDescription();
+#if defined(XP_UNIX)
+const char* NPP_GetMIMEDescription(void);
 #endif
 
 NPError NP_LOADDS NPP_Initialize();
@@ -493,52 +522,54 @@ void    NP_LOADDS NPP_Print(NPP instance, NPPrint* platformPrint);
 int16_t NP_LOADDS NPP_HandleEvent(NPP instance, void* event);
 void    NP_LOADDS NPP_URLNotify(NPP instance, const char* url,
                                 NPReason reason, void* notifyData);
-
 NPError NP_LOADDS NPP_GetValue(void * instance, NPPVariable variable, void *value);
 NPError NP_LOADDS NPP_SetValue(NPP instance, NPNVariable variable, void *value);
+NPBool  NP_LOADDS NPP_GotFocus(NPP instance, NPFocusDirection direction);
+void    NP_LOADDS NPP_LostFocus(NPP instance);
+void    NP_LOADDS NPP_URLRedirectNotify(NPP instance, const char* url, int32_t status, void* notifyData);
+NPError NP_LOADDS NPP_ClearSiteData(const char* site, uint64_t flags, uint64_t maxAge);
+char**  NP_LOADDS NPP_GetSitesWithData(void);
 
 /* NPN_* functions are provided by the navigator and called by the plugin. */
-
 void        NP_LOADDS NPN_Version(int* plugin_major, int* plugin_minor,
-                              int* netscape_major, int* netscape_minor);
+                                  int* netscape_major, int* netscape_minor);
 NPError     NP_LOADDS NPN_GetURLNotify(NPP instance, const char* url,
-                                   const char* target, void* notifyData);
+                                       const char* target, void* notifyData);
 NPError     NP_LOADDS NPN_GetURL(NPP instance, const char* url,
-                             const char* target);
+                                 const char* target);
 NPError     NP_LOADDS NPN_PostURLNotify(NPP instance, const char* url,
-                                    const char* target, uint32_t len,
-                                    const char* buf, NPBool file,
-                                    void* notifyData);
+                                        const char* target, uint32_t len,
+                                        const char* buf, NPBool file,
+                                        void* notifyData);
 NPError     NP_LOADDS NPN_PostURL(NPP instance, const char* url,
-                              const char* target, uint32_t len,
-                              const char* buf, NPBool file);
+                                  const char* target, uint32_t len,
+                                  const char* buf, NPBool file);
 NPError     NP_LOADDS NPN_RequestRead(NPStream* stream, NPByteRange* rangeList);
 NPError     NP_LOADDS NPN_NewStream(NPP instance, NPMIMEType type,
-                                const char* target, NPStream** stream);
-int32_t     NP_LOADDS NPN_Write(NPP instance, NPStream* stream, int32_t len, 
+                                    const char* target, NPStream** stream);
+int32_t     NP_LOADDS NPN_Write(NPP instance, NPStream* stream, int32_t len,
                                 void* buffer);
-NPError     NP_LOADDS NPN_DestroyStream(NPP instance, NPStream* stream, 
+NPError     NP_LOADDS NPN_DestroyStream(NPP instance, NPStream* stream,
                                         NPReason reason);
 void        NP_LOADDS NPN_Status(NPP instance, const char* message);
-const char* NP_LOADDS	NPN_UserAgent(NPP instance);
+const char* NP_LOADDS NPN_UserAgent(NPP instance);
 void*       NP_LOADDS NPN_MemAlloc(uint32_t size);
 void        NP_LOADDS NPN_MemFree(void* ptr);
 uint32_t    NP_LOADDS NPN_MemFlush(uint32_t size);
 void        NP_LOADDS NPN_ReloadPlugins(NPBool reloadPages);
-
-NPError     NP_LOADDS NPN_GetValue(NPP instance, NPNVariable variable, 
+NPError     NP_LOADDS NPN_GetValue(NPP instance, NPNVariable variable,
                                    void *value);
-NPError     NP_LOADDS NPN_SetValue(NPP instance, NPPVariable variable, 
+NPError     NP_LOADDS NPN_SetValue(NPP instance, NPPVariable variable,
                                    void *value);
 void        NP_LOADDS NPN_InvalidateRect(NPP instance, NPRect *invalidRect);
-void        NP_LOADDS NPN_InvalidateRegion(NPP instance, 
+void        NP_LOADDS NPN_InvalidateRegion(NPP instance,
                                            NPRegion invalidRegion);
 void        NP_LOADDS NPN_ForceRedraw(NPP instance);
 void        NP_LOADDS NPN_PushPopupsEnabledState(NPP instance, NPBool enabled);
 void        NP_LOADDS NPN_PopPopupsEnabledState(NPP instance);
 void        NP_LOADDS NPN_PluginThreadAsyncCall(NPP instance,
-                                            void (*func) (void *),
-                                            void *userData);
+                                                void (*func) (void *),
+                                                void *userData);
 NPError     NP_LOADDS NPN_GetValueForURL(NPP instance, NPNURLVariable variable,
                                          const char *url, char **value,
                                          uint32_t *len);
@@ -557,7 +588,9 @@ uint32_t    NP_LOADDS NPN_ScheduleTimer(NPP instance, uint32_t interval, NPBool
 void        NP_LOADDS NPN_UnscheduleTimer(NPP instance, uint32_t timerID);
 NPError     NP_LOADDS NPN_PopUpContextMenu(NPP instance, NPMenu* menu);
 NPBool      NP_LOADDS NPN_ConvertPoint(NPP instance, double sourceX, double sourceY, NPCoordinateSpace sourceSpace, double *destX, double *destY, NPCoordinateSpace destSpace);
-
+NPBool      NP_LOADDS NPN_HandleEvent(NPP instance, void *event, NPBool handled);
+NPBool      NP_LOADDS NPN_UnfocusInstance(NPP instance, NPFocusDirection direction);
+void        NP_LOADDS NPN_URLRedirectResponse(NPP instance, void* notifyData, NPBool allow);
 
 #ifdef __cplusplus
 }  /* end extern "C" */
